@@ -12,6 +12,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import random
+import string
+
 from novaclient import exceptions as nova_exceptions
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -21,7 +24,6 @@ from octavia.common import constants
 from octavia.common import data_models as models
 from octavia.common import exceptions
 from octavia.compute import compute_base
-from octavia.i18n import _LE, _LW
 
 LOG = logging.getLogger(__name__)
 
@@ -48,20 +50,17 @@ def _extract_amp_image_id_by_tag(client, image_tag, image_owner):
     image_id = images[0]['id']
     num_images = len(images)
     if num_images > 1:
-        LOG.warning(
-            _LW("A single Glance image should be tagged with %(tag)s tag, "
-                "but at least two were found. Using %(image_id)s."),
-            {'tag': image_tag, 'image_id': image_id}
-        )
+        LOG.warning("A single Glance image should be tagged with %(tag)s tag, "
+                    "but at least two were found. Using %(image_id)s.",
+                    {'tag': image_tag, 'image_id': image_id})
     return image_id
 
 
 def _get_image_uuid(client, image_id, image_tag, image_owner):
     if image_id:
         if image_tag:
-            LOG.warning(
-                _LW("Both amp_image_id and amp_image_tag options defined. "
-                    "Using the amp_image_id."))
+            LOG.warning("Both amp_image_id and amp_image_tag options defined. "
+                        "Using the amp_image_id.")
         return image_id
 
     return _extract_amp_image_id_by_tag(client, image_tag, image_owner)
@@ -105,18 +104,21 @@ class VirtualMachineManager(compute_base.ComputeBase):
         :param network_ids: Network IDs to include on virtual machine
         :param port_ids: Port IDs to include on virtual machine
         :param config_drive_files:  An optional dict of files to overwrite on
-        the server upon boot. Keys are file names (i.e. /etc/passwd)
-        and values are the file contents (either as a string or as
-        a file-like object). A maximum of five entries is allowed,
-        and each file must be 10k or less.
+                                    the server upon boot. Keys are file names
+                                    (i.e. /etc/passwd) and values are the file
+                                    contents (either as a string or as a
+                                    file-like object). A maximum of five
+                                    entries is allowed, and each file must be
+                                    10k or less.
         :param user_data: Optional user data to pass to be exposed by the
-        metadata server this can be a file type object as well or
-        a string
+                          metadata server this can be a file type object as
+                          well or a string
         :param server_group_id: Optional server group id(uuid) which is used
-        for anti_affinity feature
+                                for anti_affinity feature
 
         :raises ComputeBuildException: if nova failed to build virtual machine
         :returns: UUID of amphora
+
         '''
 
         try:
@@ -133,6 +135,14 @@ class VirtualMachineManager(compute_base.ComputeBase):
 
             image_id = _get_image_uuid(
                 self._glance_client, image_id, image_tag, image_owner)
+
+            if CONF.nova.random_amphora_name_length:
+                r = random.SystemRandom()
+                name = "a{}".format("".join(
+                    [r.choice(string.ascii_uppercase + string.digits)
+                     for i in range(CONF.nova.random_amphora_name_length - 1)]
+                ))
+
             amphora = self.manager.create(
                 name=name, image=image_id, flavor=amphora_flavor,
                 key_name=key_name, security_groups=sec_groups,
@@ -140,13 +150,14 @@ class VirtualMachineManager(compute_base.ComputeBase):
                 files=config_drive_files,
                 userdata=user_data,
                 config_drive=True,
-                scheduler_hints=server_group
+                scheduler_hints=server_group,
+                availability_zone=CONF.nova.availability_zone
             )
 
             return amphora.id
-        except Exception:
-            LOG.exception(_LE("Error building nova virtual machine."))
-            raise exceptions.ComputeBuildException()
+        except Exception as e:
+            LOG.exception("Nova failed to build the instance due to: %s", e)
+            raise exceptions.ComputeBuildException(fault=e)
 
     def delete(self, compute_id):
         '''Delete a virtual machine.
@@ -156,10 +167,10 @@ class VirtualMachineManager(compute_base.ComputeBase):
         try:
             self.manager.delete(server=compute_id)
         except nova_exceptions.NotFound:
-            LOG.warning(_LW("Nova instance with id: %s not found. "
-                            "Assuming already deleted."), compute_id)
+            LOG.warning("Nova instance with id: %s not found. "
+                        "Assuming already deleted.", compute_id)
         except Exception:
-            LOG.exception(_LE("Error deleting nova virtual machine."))
+            LOG.exception("Error deleting nova virtual machine.")
             raise exceptions.ComputeDeleteException()
 
     def status(self, compute_id):
@@ -169,11 +180,11 @@ class VirtualMachineManager(compute_base.ComputeBase):
         :returns: constant of amphora status
         '''
         try:
-            amphora = self.get_amphora(compute_id)
+            amphora, fault = self.get_amphora(compute_id)
             if amphora and amphora.status == 'ACTIVE':
                 return constants.UP
         except Exception:
-            LOG.exception(_LE("Error retrieving nova virtual machine status."))
+            LOG.exception("Error retrieving nova virtual machine status.")
             raise exceptions.ComputeStatusException()
         return constants.DOWN
 
@@ -182,12 +193,13 @@ class VirtualMachineManager(compute_base.ComputeBase):
 
         :param amphora_id: virtual machine UUID
         :returns: an amphora object
+        :returns: fault message or None
         '''
         # utilize nova client ServerManager 'get' method to retrieve info
         try:
             amphora = self.manager.get(compute_id)
         except Exception:
-            LOG.exception(_LE("Error retrieving nova virtual machine."))
+            LOG.exception("Error retrieving nova virtual machine.")
             raise exceptions.ComputeGetException()
         return self._translate_amphora(amphora)
 
@@ -196,23 +208,28 @@ class VirtualMachineManager(compute_base.ComputeBase):
 
         :param nova_response: JSON response from nova
         :returns: an amphora object
+        :returns: fault message or None
         '''
         # Extract interfaces of virtual machine to populate desired amphora
         # fields
 
         lb_network_ip = None
+        fault = None
 
         try:
             inf_list = nova_response.interface_list()
+            no_boot_networks = (
+                not CONF.controller_worker.amp_boot_network_list)
             for interface in inf_list:
                 net_id = interface.net_id
-                if net_id in CONF.controller_worker.amp_boot_network_list:
-                    lb_network_ip = interface.fixed_ips[0]['ip_address']
-                    break
-                elif net_id == CONF.controller_worker.amp_network:
-                    # TODO(ptoohill) deprecated, remove this block when ready..
+                is_boot_network = (
+                    net_id in CONF.controller_worker.amp_boot_network_list)
+                # Pick the first fixed_ip if this is a boot network or if
+                # there are no boot networks configured (use default network)
+                if is_boot_network or no_boot_networks:
                     lb_network_ip = interface.fixed_ips[0]['ip_address']
                     break
+            fault = getattr(nova_response, 'fault', None)
         except Exception:
             LOG.debug('Extracting virtual interfaces through nova '
                       'os-interfaces extension failed.')
@@ -222,7 +239,7 @@ class VirtualMachineManager(compute_base.ComputeBase):
             status=nova_response.status,
             lb_network_ip=lb_network_ip
         )
-        return response
+        return response, fault
 
     def create_server_group(self, name, policy):
         """Create a server group object
@@ -238,7 +255,7 @@ class VirtualMachineManager(compute_base.ComputeBase):
             server_group_obj = self.server_groups.create(**kwargs)
             return server_group_obj
         except Exception:
-            LOG.exception(_LE("Error create server group instance."))
+            LOG.exception("Error create server group instance.")
             raise exceptions.ServerGroupObjectCreateException()
 
     def delete_server_group(self, server_group_id):
@@ -251,8 +268,8 @@ class VirtualMachineManager(compute_base.ComputeBase):
             self.server_groups.delete(server_group_id)
 
         except nova_exceptions.NotFound:
-            LOG.warning(_LW("Server group instance with id: %s not found. "
-                            "Assuming already deleted."), server_group_id)
+            LOG.warning("Server group instance with id: %s not found. "
+                        "Assuming already deleted.", server_group_id)
         except Exception:
-            LOG.exception(_LE("Error delete server group instance."))
+            LOG.exception("Error delete server group instance.")
             raise exceptions.ServerGroupObjectDeleteException()
