@@ -12,51 +12,47 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
+import mock
 
 from octavia.cmd import health_manager
 from octavia.tests.unit import base
 
-if six.PY2:
-    import mock
-else:
-    import unittest.mock as mock
-
 
 class TestHealthManagerCMD(base.TestCase):
 
     def setUp(self):
         super(TestHealthManagerCMD, self).setUp()
 
-    @mock.patch('octavia.controller.healthmanager.'
-                'update_stats_mixin.UpdateStatsMixin')
-    @mock.patch('octavia.controller.healthmanager.'
-                'update_health_mixin.UpdateHealthMixin')
     @mock.patch('octavia.amphorae.drivers.health.'
                 'heartbeat_udp.UDPStatusGetter')
-    def test_hm_listener(self, mock_getter, mock_health, mock_stats):
+    def test_hm_listener(self, mock_getter):
         getter_mock = mock.MagicMock()
         check_mock = mock.MagicMock()
         getter_mock.check = check_mock
         getter_mock.check.side_effect = [None, Exception('break')]
         mock_getter.return_value = getter_mock
-        self.assertRaisesRegexp(Exception, 'break',
-                                health_manager.hm_listener)
-        mock_getter.assert_called_once_with(mock_health(), mock_stats())
-        self.assertEqual(getter_mock.check.call_count, 2)
+        self.assertRaisesRegex(Exception, 'break',
+                               health_manager.hm_listener)
+        mock_getter.assert_called_once()
+        self.assertEqual(2, getter_mock.check.call_count)
 
+    @mock.patch('octavia.cmd.health_manager.true_func')
     @mock.patch('octavia.controller.healthmanager.'
                 'health_manager.HealthManager')
-    def test_hm_health_check(self, mock_health):
+    def test_hm_health_check(self, mock_health, mock_true_func):
         hm_mock = mock.MagicMock()
         health_check_mock = mock.MagicMock()
         hm_mock.health_check = health_check_mock
         hm_mock.health_check.side_effect = [None, Exception('break')]
+        mock_true_func.side_effect = [True, True, Exception('break')]
         mock_health.return_value = hm_mock
-        self.assertRaisesRegexp(Exception, 'break',
-                                health_manager.hm_health_check)
+        self.assertRaisesRegex(Exception, 'break',
+                               health_manager.hm_health_check)
         mock_health.assert_called_once_with()
-        self.assertEqual(hm_mock.health_check.call_count, 2)
+        self.assertEqual(2, hm_mock.health_check.call_count)
+
+    def test_hm_true_func(self):
+        self.assertTrue(health_manager.true_func())
 
     @mock.patch('multiprocessing.Process')
     @mock.patch('octavia.common.service.prepare_service')
